@@ -182,7 +182,7 @@ class BulbDevice(Device):
             r = int(hexvalue[0:2], 16)
             g = int(hexvalue[2:4], 16)
             b = int(hexvalue[4:6], 16)
-        if bulb == "B":
+        elif bulb == "B":
             # hexvalue is in hsv
             h = float(int(hexvalue[0:4], 16) / 360.0)
             s = float(int(hexvalue[4:8], 16) / 1000.0)
@@ -191,6 +191,9 @@ class BulbDevice(Device):
             r = int(rgb[0] * 255)
             g = int(rgb[1] * 255)
             b = int(rgb[2] * 255)
+        else:
+            # Unsupported bulb type
+            raise ValueError(f"Unsupported bulb type {bulb} - unable to determine RGB values.")
 
         return (r, g, b)
 
@@ -207,12 +210,15 @@ class BulbDevice(Device):
             h = int(hexvalue[7:10], 16) / 360.0
             s = int(hexvalue[10:12], 16) / 255.0
             v = int(hexvalue[12:14], 16) / 255.0
-        if bulb == "B":
+        elif bulb == "B":
             # hexvalue is in hsv
             h = int(hexvalue[0:4], 16) / 360.0
             s = int(hexvalue[4:8], 16) / 1000.0
             v = int(hexvalue[8:12], 16) / 1000.0
-
+        else:
+            # Unsupported bulb type
+            raise ValueError(f"Unsupported bulb type {bulb} - unable to determine HSV values.")
+        
         return (h, s, v)
 
     def set_version(self, version): # pylint: disable=W0621
